``ExposoGraph.example_graphs``
==============================

Curated showcase builders and manuscript-aligned architecture summaries.

Data Structures
---------------

.. autoclass:: ExposoGraph.example_graphs.ArchitectureInventoryGroup
   :members:

.. autoclass:: ExposoGraph.example_graphs.ArchitectureSummary
   :members:

Showcase Builders
-----------------

.. autofunction:: ExposoGraph.example_graphs.build_androgen_module_graph

.. autofunction:: ExposoGraph.example_graphs.build_androgen_module_engine

.. autofunction:: ExposoGraph.example_graphs.build_full_legends_graph

.. autofunction:: ExposoGraph.example_graphs.build_full_legends_engine

.. autofunction:: ExposoGraph.example_graphs.build_full_legends_architecture_summary

.. autofunction:: ExposoGraph.example_graphs.write_full_legends_exports
